# promisio

[![Build status](https://github.com/miguelgrinberg/promisio/workflows/build/badge.svg)](https://github.com/miguelgrinberg/promisio/actions) [![codecov](https://codecov.io/gh/miguelgrinberg/promisio/branch/main/graph/badge.svg)](https://codecov.io/gh/miguelgrinberg/promisio)

JavaScript-style async programming for Python.

## Examples

TODO

## Resources

- [Documentation](http://promisio.readthedocs.io/en/latest/)
- [PyPI](https://pypi.python.org/pypi/promisio)
- [Change Log](https://github.com/miguelgrinberg/promisio/blob/main/CHANGES.md)

